==> ivs-1.93.0-sources.jar: software/amazon/awscdk/services/ivs/StreamKey.java <==
package software.amazon.awscdk.services.ivs;

/**
 * (experimental) A new IVS Stream Key.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:21.823Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ivs.$Module.class, fqn = "@aws-cdk/aws-ivs.StreamKey")
public class StreamKey extends software.amazon.awscdk.core.Resource implements software.amazon.awscdk.services.ivs.IStreamKey {

    protected StreamKey(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected StreamKey(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public StreamKey(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ivs.StreamKeyProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * (experimental) The stream-key ARN.
     * <p>
     * For example: arn:aws:ivs:us-west-2:123456789012:stream-key/g1H2I3j4k5L6
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getStreamKeyArn() {
        return software.amazon.jsii.Kernel.get(this, "streamKeyArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) The stream-key value.
     * <p>
     * For example: sk_us-west-2_abcdABCDefgh_567890abcdef
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getStreamKeyValue() {
        return software.amazon.jsii.Kernel.get(this, "streamKeyValue", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) A fluent builder for {@link software.amazon.awscdk.services.ivs.StreamKey}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.ivs.StreamKey> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.ivs.StreamKeyProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.ivs.StreamKeyProps.Builder();
        }

        /**
         * (experimental) Channel ARN for the stream.
         * <p>
         * @return {@code this}
         * @param channel Channel ARN for the stream. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder channel(final software.amazon.awscdk.services.ivs.IChannel channel) {
            this.props.channel(channel);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.ivs.StreamKey}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public software.amazon.awscdk.services.ivs.StreamKey build() {
            return new software.amazon.awscdk.services.ivs.StreamKey(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> ivs-1.182.0-sources.jar: software/amazon/awscdk/services/ivs/StreamKey.java <==
package software.amazon.awscdk.services.ivs;

/**
 * (experimental) A new IVS Stream Key.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * StreamKey myStreamKey = myChannel.addStreamKey("StreamKey");
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:36.409Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ivs.$Module.class, fqn = "@aws-cdk/aws-ivs.StreamKey")
public class StreamKey extends software.amazon.awscdk.core.Resource implements software.amazon.awscdk.services.ivs.IStreamKey {

    protected StreamKey(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected StreamKey(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public StreamKey(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ivs.StreamKeyProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * (experimental) The stream-key ARN.
     * <p>
     * For example: arn:aws:ivs:us-west-2:123456789012:stream-key/g1H2I3j4k5L6
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getStreamKeyArn() {
        return software.amazon.jsii.Kernel.get(this, "streamKeyArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) The stream-key value.
     * <p>
     * For example: sk_us-west-2_abcdABCDefgh_567890abcdef
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getStreamKeyValue() {
        return software.amazon.jsii.Kernel.get(this, "streamKeyValue", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) A fluent builder for {@link software.amazon.awscdk.services.ivs.StreamKey}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.ivs.StreamKey> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.ivs.StreamKeyProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.ivs.StreamKeyProps.Builder();
        }

        /**
         * (experimental) Channel ARN for the stream.
         * <p>
         * @return {@code this}
         * @param channel Channel ARN for the stream. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder channel(final software.amazon.awscdk.services.ivs.IChannel channel) {
            this.props.channel(channel);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.ivs.StreamKey}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public software.amazon.awscdk.services.ivs.StreamKey build() {
            return new software.amazon.awscdk.services.ivs.StreamKey(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
